# CNCF Blog Guidelines #

## CNCF Blog Overview ##

The Cloud Native Computing Foundation (CNCF) blog is a community-driven platform designed to highlight cloud native technologies, best practices, innovations, and community experiences. Contributions are welcomed from CNCF members, project maintainers, ambassadors, mentors and mentees, scholarship recipients, and Technical Advisory Groups (TAGs).

### Preferred Content Topics: ###
* Updates and insights on CNCF Graduated or Incubating projects
* Technical guides, tutorials, and how-to articles focused on CNCF projects or broader cloud native technologies
* Real-world case studies showcasing CNCF project deployments and cloud native implementations
* Success stories illustrating effective strategies for cloud native adoption
* Thought leadership on cloud native trends, industry developments, and future outlooks
* Recaps, experiences, and insights from CNCF events

Submissions on other relevant topics may be considered if they have clear connections to CNCF projects or the wider cloud native ecosystem.

## Submission Categories ##

* CNCF members
  * Member Blog: Vendor-neutral posts from CNCF members aligned with CNCF guidelines. Members may discuss open-source projects, including CNCF Sandbox projects.
  * Posts focused solely on CNCF Graduated or Incubating projects, written on behalf of the project, will be categorized as Project Blogs.
  * If the blog includes information about a CNCF Graduated or Incubating project with instructional or tutorial content (e.g., how-to guides), it remains classified as a Member Blog.
      * Members can add 1-2 sentences at the end of their blog with a link to an external site such as their website or a gated asset. Examples for best practices:
      * Share contact info of  speaker - twitter, slack, email
      * Links to company websites
      * Links to projects websites or Github
      * Can advertise if they are hiring and who to contact if interested

* Project Maintainers (Graduated and Incubating Projects)
   * Project blog: Blog posts specifically focused on CNCF Graduated or Incubating projects. These posts are authored by the project maintainers or written on behalf of the project. For example, a Harbor project blog authored by VMware team members is classified as a Project Blog.

* CNCF Technical Advisory Groups (TAGs)
   * TAG Blog: Blog posts authored by CNCF TAG members or by CNCF members explicitly on behalf of a TAG are classified as TAG Blogs.
   * If a CNCF member writes independently about a TAG (not on behalf of the TAG), the blog is classified as a Member Blog

* CNCF Ambassadors
  * Ambassador blog: Blog posts authored by CNCF Ambassadors. Ambassadors may submit up to two blog posts per month. These blogs may include pieces on expertise, thought leadership, insights, and personal experience.

* CNCF Mentor + Mentees
  * Mentorship blog: Sharing experiences, learnings, insights, and the impact of participation in CNCF mentorship programs

* Scholarship Recipients
  * Scholarship blog: Posts detailing personal experiences from CNCF events, discussing the impact of receiving a CNCF scholarship, and highlighting how it contributed to personal or professional goals.

All submissions should be original content published within the past two months. CNCF does not accept paid or sponsored blog posts.



## Content Guidelines ##
The primary audience for CNCF blogs is developers, IT operators, and cloud native and open-source enthusiasts. Please ensure your content addresses their interests and needs

### Best Practices: ###
* Vendor-Neutrality: Mention vendors only in contexts directly related to open-source projects, meaningful community participation, or event involvement. Promotional or advertising content, announcements, and press releases are not accepted.

* Technical & Educational Value: Strongly encouraged are how-to articles, technical deep dives, tutorials, and innovative use-cases.

* Community Relevance: Posts describing real-world challenges and the solutions adopted often generate significant community interest.

*  Comparative and Analytical Content: Articles helping readers navigate choices among technologies or solutions addressing legacy issues or cloud platform compatibility are valuable.

* Links to Upstream Contributions: When referencing project contributions, always link back to relevant GitHub issues or pull requests.

*  Constructive Criticism: Address sensitive or broad industry issues constructively and professionally, aiming for positive impacts on the community.

*  Originality & Licensing: Ensure content is original or provide explicit permission for republication. All posts must follow the Creative Commons Attribution license.

(Note: Links to CNCF websites or CNCF forms are not permitted.)

CNCF will review and approve all content, including any concluding statements. Suggested edits may be provided as needed

## Promotion ##
You are encouraged to promote published blogs through social media. 

## Submission Process ##
1. Proposal
   * Submit your blog post in a google doc or word document with any images that needed to uploaded to [Marketing Submission Form](https://form.asana.com/?k=Ufi_ZE31X3EAKMTiplIEcA&d=9283783873717).
   * For previously published content, include the complete article or presentation along with explicit permission for republishing.
2. Review
   *  The CNCFteam will typically responds within 7–10 business days, though response times may be longer around KubeCon + CloudNativeCon events due to increased volume.
   *  If the proposal meets the criteria, and no edits are required the marketing team will reach out with an expected publication date. Please note that delivery or publication may take 2–3 weeks, depending on scope and complexity.
   *  If the proposal doesn’t meet the criteria, the CNCF team will provide feedback for the author.
3. Editng
   * CNCF reviews the blog and makes any necessary edits as suggestions
4. Publishing
   * CNCF prepares the blog for publication
   * Generally blog posts can be scheduled for publication approximately two weeks after submission. It may be longer if there is a CNCF event taking place around the time of submission. The marketing team will communicate potential publication dates and/or changes to those dates.
   * Blogs are published to [https://www.cncf.io/blog/](https://www.cncf.io/blog/)
  

